# sphinx-jinja2

[![PyPI][pypi-badge]][pypi-link]

> A sphinx extension to add the `jinja` directive, for rendering jinja templates.

**Note:** This is an adaption of [https://github.com/tardyp/sphinx-jinja](https://github.com/tardyp/sphinx-jinja), which appears to be unmaintained.

See [the documentation](https://sphinx-jinja2.readthedocs.io) for more information.

TODO: allow tests/filters to be strings, pointing to python import paths.
This is because Sphinx cannot cache lambda functions, so full rebuilds are always triggered.

[pypi-badge]: https://img.shields.io/pypi/v/sphinx-jinja2.svg
[pypi-link]: https://pypi.org/project/sphinx-jinja2
